@@ -139,8 +139,10 @@ if plat[:5] == 'linux':    # Linux (confirmed)  # noqa
                         buf[0] |= SER_RS485_RTS_AFTER_SEND
                     else:
                         buf[0] &= ~SER_RS485_RTS_AFTER_SEND
-                    buf[1] = int(rs485_settings.delay_before_tx * 1000)
-                    buf[2] = int(rs485_settings.delay_before_rx * 1000)
+                    if rs485_settings.delay_before_tx is not None:
+                        buf[1] = int(rs485_settings.delay_before_tx * 1000)
+                    if rs485_settings.delay_before_rx is not None:
+                        buf[2] = int(rs485_settings.delay_before_rx * 1000)
                 else:
                     buf[0] = 0  # clear SER_RS485_ENABLED
                 fcntl.ioctl(self.fd, TIOCSRS485, buf)
@@ -271,6 +273,8 @@ class Serial(SerialBase, PlatformSpecific):
         self.reset_input_buffer()
         self.pipe_abort_read_r, self.pipe_abort_read_w = os.pipe()
         self.pipe_abort_write_r, self.pipe_abort_write_w = os.pipe()
+        fcntl.fcntl(self.pipe_abort_read_r, fcntl.F_SETFL, os.O_NONBLOCK)
+        fcntl.fcntl(self.pipe_abort_write_r, fcntl.F_SETFL, os.O_NONBLOCK)
 
     def _reconfigure_port(self, force_update=False):
         """Set communication parameters on opened port."""
@@ -445,7 +449,7 @@ class Serial(SerialBase, PlatformSpecific):
                 start_time = time.time()
                 ready, _, _ = select.select([self.fd, self.pipe_abort_read_r], [], [], timeout)
                 if self.pipe_abort_read_r in ready:
-                    os.read(self.pipe_abort_read_r, 1)
+                    os.read(self.pipe_abort_read_r, 1000)
                     break
                 # If select was used with a timeout, and the timeout occurs, it
                 # returns with empty lists -> thus abort read operation.
@@ -464,14 +468,10 @@ class Serial(SerialBase, PlatformSpecific):
                         'device reports readiness to read but returned no data '
                         '(device disconnected or multiple access on port?)')
                 read.extend(buf)
-                if timeout is not None:
-                    timeout -= time.time() - start_time
-                    if timeout <= 0:
-                        break
             except OSError as e:
                 # this is for Python 3.x where select.error is a subclass of
                 # OSError ignore EAGAIN errors. all other errors are shown
-                if e.errno != errno.EAGAIN:
+                if e.errno != errno.EAGAIN and e.errno != errno.EINTR:
                     raise SerialException('read failed: {}'.format(e))
             except select.error as e:
                 # this is for Python 2.x
@@ -479,6 +479,10 @@ class Serial(SerialBase, PlatformSpecific):
                 # see also http://www.python.org/dev/peps/pep-3151/#select
                 if e[0] != errno.EAGAIN:
                     raise SerialException('read failed: {}'.format(e))
+            if timeout is not None:
+                timeout -= time.time() - start_time
+                if timeout <= 0:
+                    break
         return bytes(read)
 
     def cancel_read(self):
@@ -511,7 +515,7 @@ class Serial(SerialBase, PlatformSpecific):
                         raise writeTimeoutError
                     abort, ready, _ = select.select([self.pipe_abort_write_r], [self.fd], [], timeleft)
                     if abort:
-                        os.read(self.pipe_abort_write_r, 1)
+                        os.read(self.pipe_abort_write_r, 1000)
                         break
                     if not ready:
                         raise writeTimeoutError
@@ -633,12 +637,6 @@ class Serial(SerialBase, PlatformSpecific):
         s = fcntl.ioctl(self.fd, TIOCOUTQ, TIOCM_zero_str)
         return struct.unpack('I', s)[0]
 
-    def nonblocking(self):
-        """internal - not portable!"""
-        if not self.is_open:
-            raise portNotOpenError
-        fcntl.fcntl(self.fd, fcntl.F_SETFL, os.O_NONBLOCK)
-
     def fileno(self):
         """\
         For easier use of the serial port instance with select.
@@ -674,6 +672,11 @@ class Serial(SerialBase, PlatformSpecific):
         else:
             termios.tcflow(self.fd, termios.TCOOFF)
 
+    def nonblocking(self):
+        """DEPRECATED - has no use"""
+        import warnings
+        warnings.warn("nonblocking() has no effect, already nonblocking", DeprecationWarning)
+
 
 class PosixPollSerial(Serial):
     """\
